@@ -1,3 +1,4 @@
+from typing import *
 import telegram
 from royalnet.commands import *
 
@@ -5,7 +6,7 @@ from royalnet.commands import *
 class CiaoruoziCommand(Command):
     name: str = "ciaoruozi"
 
-    description: str = "Saluta Ruozi, un leggendario essere che una volta era in User Games."
+    description: str = "Saluta Ruozi, un leggendario essere che è tornato in Royal Games."
 
     async def run(self, args: CommandArgs, data: CommandData) -> None:
         if self.interface.name == "telegram":
