@@ -23,6 +23,8 @@ class FunkwhalealbumCommand(PlayCommand):
         async with aiohttp.ClientSession() as session:
             async with session.get(self.config["Funkwhale"]["instance_url"] +
                                    f"/api/v1/search?query={search}") as response:
+                if response.status >= 400:
+                    raise rc.ExternalError(f"Request returned {response.status}")
                 j = await response.json()
         if len(j["albums"]) < 1:
             raise rc.UserError("Nessun file audio trovato con il nome richiesto.")
