@@ -16,6 +16,8 @@ from .pollvotes import PollVote
 from .brawlhalladuos import BrawlhallaDuo
 from .mmevents import MMEvent
 from .mmresponse import MMResponse
+from .cvstats import Cvstats
+from .treasure import Treasure
 
 # Enter the tables of your Pack here!
 available_tables = [
@@ -36,6 +38,8 @@ available_tables = [
     BrawlhallaDuo,
     MMEvent,
     MMResponse,
+    Cvstats,
+    Treasure,
 ]
 
 # Don't change this, it should automatically generate __all__
