@@ -3,8 +3,8 @@ import enum
 
 class MMChoice(enum.Enum):
     YES = "🔵"
-    MAYBE = "❔"
     LATE_SHORT = "🕐"
     LATE_MEDIUM = "🕒"
     LATE_LONG = "🕗"
+    MAYBE = "❓"
     NO = "❌"
